@@ -1708,5 +1708,8 @@ pref("image.http.accept", "image/png,image/*;q=0.8,*/*;q=0.5");
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
 
+// Enable/Disable the orientation API for content
+pref("accelerometer.enabled", true);
+
 // Enable/Disable HTML5 parser
 pref("html5.enable", false);
